@@ -141,17 +141,8 @@ Opal::Call::answer ()
 void
 Opal::Call::transfer (std::string uri)
 {
-  PSafePtr<OpalConnection> connection = NULL;
-
-  int i = 0;
-
-  do {
-
-    connection = GetConnection (i);
-    i++;
-  }  while (PIsDescendant(&(*connection), OpalPCSSConnection));
-
-  if (connection)
+  PSafePtr<OpalConnection> connection = get_remote_connection ();
+  if (connection != NULL)
     connection->TransferConnection (uri);
 }
 
@@ -159,18 +150,9 @@ Opal::Call::transfer (std::string uri)
 void
 Opal::Call::toggle_hold ()
 {
-  PSafePtr<OpalConnection> connection = NULL;
-
   bool on_hold = false;
-  int i = 0;
-
-  do {
-
-    connection = GetConnection (i);
-    i++;
-  }  while (PIsDescendant(&(*connection), OpalPCSSConnection));
-
-  if (connection) {
+  PSafePtr<OpalConnection> connection = get_remote_connection ();
+  if (connection != NULL) {
 
     on_hold = connection->IsConnectionOnHold ();
     if (!on_hold)
@@ -185,20 +167,12 @@ void
 Opal::Call::toggle_stream_pause (StreamType type)
 {
   OpalMediaStreamPtr stream = NULL;
-  PSafePtr<OpalConnection> connection = NULL;
   PString codec_name;
   std::string stream_name;
 
   bool paused = false;
 
-  int i = 0;
-
-  do {
-
-    connection = GetConnection (i);
-    i++;
-  }  while (PIsDescendant(&(*connection), OpalPCSSConnection));
-
+  PSafePtr<OpalConnection> connection = get_remote_connection ();
   if (connection != NULL) {
 
     stream = connection->GetMediaStream ((type == Audio) ? OpalMediaType::Audio () : OpalMediaType::Video (), false);
@@ -221,18 +195,10 @@ Opal::Call::toggle_stream_pause (StreamType type)
 void
 Opal::Call::send_dtmf (const char dtmf)
 {
-  PSafePtr<OpalConnection> connection = NULL;
-
-  int i = 0;
-
-  do {
-
-    connection = GetConnection (i);
-    i++;
-  }  while (PIsDescendant(&(*connection), OpalPCSSConnection));
-
-  if (connection != NULL)
+  PSafePtr<OpalConnection> connection = get_remote_connection ();
+  if (connection != NULL) {
     connection->SendUserInputTone (dtmf, 180);
+  }
 }
 
 
@@ -667,19 +633,12 @@ void
 Opal::Call::OnNoAnswerTimeout (PTimer &,
                                INT) 
 {
-  PSafePtr<OpalConnection> connection = NULL;
-  int i = 0;
-
   if (!is_outgoing ()) {
 
     if (!forward_uri.empty ()) {
 
-      do {
-        connection = GetConnection (i);
-        i++;
-      }  while (PIsDescendant(&(*connection), OpalPCSSConnection));
-
-      if (!PIsDescendant(&(*connection), OpalPCSSConnection)) 
+      PSafePtr<OpalConnection> connection = get_remote_connection ();
+      if (connection != NULL)
         connection->ForwardCall (forward_uri);
     }
     else
