@@ -77,12 +77,9 @@ void GMAudioInputManager_ptlib::get_devices(std::vector <Ekiga::AudioInputDevice
 
       for (PINDEX j = 0; devices_array[j] != NULL; j++) {
 
-#ifdef WIN32
-        device.name = devices_array[j];
-#else
-        // linux USB subsystem uses latin-1 encoding, while ekiga uses utf-8
+        /* linux USB subsystem uses latin-1 encoding, Windows codepage,
+           while ekiga uses utf-8 */
         device.name = latin2utf (devices_array[j]);
-#endif
         devices.push_back(device);
       }
       free (devices_array);
@@ -113,11 +110,7 @@ bool GMAudioInputManager_ptlib::open (unsigned channels, unsigned samplerate, un
   current_state.bits_per_sample = bits_per_sample;
 
   input_device = PSoundChannel::CreateOpenedChannel (current_state.device.source,
-#ifdef WIN32
-                                                     current_state.device.name,
-#else
-                                                     utf2latin (current_state.device.name),  // reencode back to latin-1
-#endif
+                                                     utf2latin (current_state.device.name),  // reencode back to latin-1 or codepage
                                                      PSoundChannel::Recorder,
                                                      channels,
                                                      samplerate,
@@ -183,12 +176,11 @@ bool GMAudioInputManager_ptlib::get_frame_data (char *data,
       bytes_read = input_device->GetLastReadCount();
     }
     if (bytes_read != size) {
-      PTRACE(1, "GMAudioInputManager_ptlib\tEncountered error while trying to read data");
-      Ekiga::Runtime::run_in_main (sigc::bind (sigc::mem_fun (this, &GMAudioInputManager_ptlib::device_error_in_main), current_state.device, Ekiga::AI_ERROR_READ));
+      PTRACE(1, "GMAudioInputManager_ptlib\tRead " << bytes_read << " instead of " << size);
     }
   }
 
-  return (ret || bytes_read == size);
+  return (ret);
 }
 
 void GMAudioInputManager_ptlib::set_volume (unsigned volume)
