@@ -149,7 +149,7 @@ Ekiga::FormBuilder::hidden (const std::string name) const
     if (iter->name == name)
       return iter->value;
 
-  throw Ekiga::Form::not_found (name);
+  return ""; // shouldn't happen
 }
 
 bool
@@ -161,7 +161,7 @@ Ekiga::FormBuilder::boolean (const std::string name) const
     if (iter->name == name)
       return iter->value;
 
-  throw Ekiga::Form::not_found (name);
+  return false; // shouldn't happen
 }
 
 const std::string
@@ -173,7 +173,7 @@ Ekiga::FormBuilder::private_text (const std::string name) const
     if (iter->name == name)
       return iter->value;
 
-  throw Ekiga::Form::not_found (name);
+  return ""; // shouldn't happen
 }
 
 const std::string
@@ -185,7 +185,7 @@ Ekiga::FormBuilder::text (const std::string name) const
     if (iter->name == name)
       return iter->value;
 
-  throw Ekiga::Form::not_found (name);
+  return ""; // shouldn't happen
 }
 
 const std::string
@@ -197,7 +197,7 @@ Ekiga::FormBuilder::multi_text (const std::string name) const
     if (iter->name == name)
       return iter->value;
 
-  throw Ekiga::Form::not_found (name);
+  return ""; // shouldn't happen
 }
 
 const std::string
@@ -209,7 +209,7 @@ Ekiga::FormBuilder::single_choice (const std::string name) const
     if (iter->name == name)
       return iter->value;
 
-  throw Ekiga::Form::not_found (name);
+  return ""; // shouldn't happen
 }
 
 const std::set<std::string>
@@ -221,7 +221,7 @@ Ekiga::FormBuilder::multiple_choice (const std::string name) const
     if (iter->name == name)
       return iter->values;
 
-  throw Ekiga::Form::not_found (name);
+  return std::set<std::string>(); // shouldn't happen
 }
 
 const std::set<std::string>
@@ -233,7 +233,7 @@ Ekiga::FormBuilder::editable_set (const std::string name) const
     if (iter->name == name)
       return iter->values;
 
-  throw Ekiga::Form::not_found (name);
+  return std::set<std::string>(); // shouldn't happen
 }
 
 void
