@@ -1,6 +1,6 @@
 
 /* Ekiga -- A VoIP and Video-Conferencing application
- * Copyright (C) 2000-2006 Damien Sandras
+ * Copyright (C) 2000-2009 Damien Sandras <dsandras@seconix.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -89,7 +89,8 @@ gm_entry_dialog_get_type (void)
       NULL,
       sizeof (GmEntryDialog),
       0,
-      (GInstanceInitFunc) gm_entry_dialog_init
+      (GInstanceInitFunc) gm_entry_dialog_init,
+      NULL
     };
     
     gm_entry_dialog_type =
