@@ -1,6 +1,6 @@
 
 /* Ekiga -- A VoIP and Video-Conferencing application
- * Copyright (C) 2000-2006 Damien Sandras
+ * Copyright (C) 2000-2009 Damien Sandras <dsandras@seconix.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -38,6 +38,7 @@
 
 #include "gmmenuaddon.h"
 
+#include <libintl.h>
 #include <gdk/gdkkeysyms.h>
 
 
@@ -65,7 +66,7 @@ static void menu_widget_destroyed (GtkWidget *,
  * PRE          :  data = the GtkWidget for the menu.
  */
 static void
-menus_have_icons_changed_nt (gpointer cid,
+menus_have_icons_changed_nt (G_GNUC_UNUSED gpointer cid,
 			     GmConfEntry *entry,
 			     gpointer data)
 {
@@ -73,12 +74,8 @@ menus_have_icons_changed_nt (gpointer cid,
 
   g_return_if_fail (gm_conf_entry_get_type (entry) == GM_CONF_BOOL && data);
   
-  gdk_threads_enter ();
-  
   show_icons = gm_conf_entry_get_bool (entry);
   gtk_menu_show_icons (GTK_WIDGET (data), show_icons);
-  
-  gdk_threads_leave ();
 }
 
 
@@ -88,7 +85,7 @@ menus_have_icons_changed_nt (gpointer cid,
  * PRE          :  data != NULL.
  */
 static gint
-popup_menu_callback (GtkWidget *widget,
+popup_menu_callback (G_GNUC_UNUSED GtkWidget *widget,
 		     GdkEventButton *event,
 		     gpointer data)
 {
@@ -158,7 +155,8 @@ menu_item_selected (GtkWidget *w,
  * PRE          :  data = the notifier id.
  */
 static void
-menu_widget_destroyed (GtkWidget *w, gpointer data)
+menu_widget_destroyed (G_GNUC_UNUSED GtkWidget *w,
+		       gpointer data)
 {  
   gm_conf_notifier_remove (data);
 }
@@ -210,7 +208,7 @@ toggle_menu_changed_cb (GtkWidget *widget,
 
 
 void 
-menu_toggle_changed_nt (gpointer id, 
+menu_toggle_changed_nt (G_GNUC_UNUSED gpointer id, 
                         GmConfEntry *entry, 
                         gpointer data)
 {
@@ -221,22 +219,18 @@ menu_toggle_changed_nt (gpointer id,
 
   if (gm_conf_entry_get_type (entry) == GM_CONF_BOOL) {
    
-    gdk_threads_enter ();
-  
     e = GTK_WIDGET (data);
 
     /* We set the new value for the widget */
     GTK_CHECK_MENU_ITEM (e)->active = gm_conf_entry_get_bool (entry);
 
     gtk_widget_queue_draw (GTK_WIDGET (e));
-
-    gdk_threads_leave (); 
   }
 }
 
 
 void
-radio_menu_changed_nt (gpointer id,
+radio_menu_changed_nt (G_GNUC_UNUSED gpointer id,
 		       GmConfEntry *entry,
 		       gpointer data)
 {
@@ -245,12 +239,8 @@ radio_menu_changed_nt (gpointer id,
 
   if (gm_conf_entry_get_type (entry) == GM_CONF_INT) {
 
-    gdk_threads_enter ();
-
     gtk_radio_menu_select_with_widget (GTK_WIDGET (data),
 				       gm_conf_entry_get_int (entry));
-
-    gdk_threads_leave ();
   }
 }
 
@@ -263,9 +253,14 @@ gtk_build_menu (GtkWidget *menubar,
 {
   GtkWidget *menu_widget = menubar;
   GtkWidget *old_menu = NULL;
-  GSList *group = NULL;
   GtkWidget *image = NULL;
+  GtkStockItem item;
+
+  GSList *group = NULL;
+  
   int i = 0;
+  gchar *menu_name = NULL;
+
   gpointer id = NULL;
   gboolean show_icons = TRUE;
 
@@ -279,17 +274,27 @@ gtk_build_menu (GtkWidget *menubar,
     if (menu [i].type != MENU_RADIO_ENTRY) 
       group = NULL;
 
-    if (menu [i].name) {
+    if (menu [i].stock_id && !menu [i].stock_is_theme && !menu [i].name) {
+
+      if (gtk_stock_lookup (menu [i].stock_id, &item))
+        menu_name = g_strdup (gettext (item.label));
+      else
+        menu_name = g_strdup (menu [i].name);
+    }
+    else 
+      menu_name = g_strdup (menu [i].name);
+
+    if (menu_name) {
 
       if (menu [i].type == MENU_ENTRY 
 	  || menu [i].type == MENU_SUBMENU_NEW
 	  || menu [i].type == MENU_NEW)
 	menu [i].widget = 
-	  gtk_image_menu_item_new_with_mnemonic (menu [i].name);
+	  gtk_image_menu_item_new_with_mnemonic (menu_name);
       else if (menu [i].type == MENU_TOGGLE_ENTRY) {
 	
 	menu [i].widget = 
-	  gtk_check_menu_item_new_with_mnemonic (menu [i].name);
+	  gtk_check_menu_item_new_with_mnemonic (menu_name);
 	GTK_CHECK_MENU_ITEM (menu [i].widget)->active =
 	  menu [i].enabled;
 	gtk_widget_queue_draw (menu [i].widget);
@@ -301,7 +306,7 @@ gtk_build_menu (GtkWidget *menubar,
 	
 	menu [i].widget = 
 	  gtk_radio_menu_item_new_with_mnemonic (group, 
-						 menu [i].name);
+						 menu_name);
 
 	GTK_CHECK_MENU_ITEM (menu [i].widget)->active =
 	  menu [i].enabled;
@@ -313,15 +318,20 @@ gtk_build_menu (GtkWidget *menubar,
 
       if (menu [i].stock_id && show_icons) {
 
-	image = gtk_image_new_from_stock (menu [i].stock_id,
-					  GTK_ICON_SIZE_MENU);
+	if (menu [i].stock_is_theme)
+	  image = gtk_image_new_from_icon_name(menu [i].stock_id,
+					       GTK_ICON_SIZE_MENU);
+	else
+	  image = gtk_image_new_from_stock (menu [i].stock_id,
+					    GTK_ICON_SIZE_MENU);
 	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu[i].widget),
 				       image);
 	gtk_widget_show (image);
       }
 
       if (menu [i].accel && accel)
-        if (menu [i].accel == GDK_F1)
+	{
+/*        if ((menu [i].accel == GDK_F1) || (menu [i].accel == GDK_F11))
           gtk_widget_add_accelerator (menu [i].widget, "activate", 
                                       accel, menu [i].accel, 
                                       0, GTK_ACCEL_VISIBLE);
@@ -329,20 +339,53 @@ gtk_build_menu (GtkWidget *menubar,
           gtk_widget_add_accelerator (menu [i].widget, "activate", 
                                       accel, menu [i].accel, 
                                       GDK_CONTROL_MASK, GTK_ACCEL_VISIBLE);
-      if (menu [i].func) 
-	g_signal_connect (G_OBJECT (menu [i].widget),
-			  "activate", menu [i].func,
-			  menu [i].data);
+*/
+	  switch (menu [i].accel) {
+		case GDK_F1:
+		case GDK_F11:
+		case GDK_Escape:
+		case GDK_h:
+		case GDK_t:
+		case GDK_m:
+		case GDK_p:
+          		gtk_widget_add_accelerator (menu [i].widget, "activate",
+                                      accel, menu [i].accel,
+                                      0, GTK_ACCEL_VISIBLE);
+			break;
+		default:
+          		gtk_widget_add_accelerator (menu [i].widget, "activate",
+                                      accel, menu [i].accel,
+                                      GDK_CONTROL_MASK, GTK_ACCEL_VISIBLE);
+			break;
+	  }		
+	}
+
+      if (menu [i].func) {
+
+        if (menu [i].clofunc) {
+          g_signal_connect_data (G_OBJECT (menu [i].widget),
+                                 "activate", menu [i].func,
+                                 menu [i].data,
+                                 (GClosureNotify) menu [i].clofunc, 
+                                 (GConnectFlags) G_CONNECT_AFTER);
+        }
+        else {
+          g_signal_connect (G_OBJECT (menu [i].widget),
+                            "activate", menu [i].func,
+                            menu [i].data);
+        }
+      }
 
       g_object_set_data (G_OBJECT (menu [i].widget),
 			 "statusbar", statusbar);
       g_signal_connect (G_OBJECT (menu [i].widget),
-			"select", GTK_SIGNAL_FUNC (menu_item_selected), 
+			"select", G_CALLBACK (menu_item_selected), 
 			(gpointer) menu [i].tooltip);
       g_signal_connect (G_OBJECT (menu [i].widget),
-			"deselect", GTK_SIGNAL_FUNC (menu_item_selected), 
+			"deselect", G_CALLBACK (menu_item_selected), 
 			NULL);
     }
+    g_free (menu_name);
 
     if (menu [i].type == MENU_SEP) {
 
@@ -417,11 +460,14 @@ gtk_build_popup_menu (GtkWidget *widget,
   gtk_build_menu (popup_menu_widget, menu, accel, NULL);
   gtk_widget_show_all (popup_menu_widget);
 
-  g_signal_connect (G_OBJECT (widget), "button_press_event",
-		    G_CALLBACK (popup_menu_callback), 
-		    (gpointer) popup_menu_widget);
+  if (widget) {
 
-  gtk_widget_add_events (widget, GDK_BUTTON_PRESS_MASK | GDK_KEY_PRESS_MASK);
+    g_signal_connect (G_OBJECT (widget), "button_press_event",
+                      G_CALLBACK (popup_menu_callback), 
+                      (gpointer) popup_menu_widget);
+
+    gtk_widget_add_events (widget, GDK_BUTTON_PRESS_MASK | GDK_KEY_PRESS_MASK);
+  }
 
   return popup_menu_widget;
 }
@@ -578,8 +624,12 @@ gtk_menu_show_icons (GtkWidget *menu, gboolean show_icons)
 
 	if (!image) {
 	  
-	  image = gtk_image_new_from_stock (menu_entry [i].stock_id,
-					    GTK_ICON_SIZE_MENU);
+	  if (menu_entry [i].stock_is_theme)
+	    image = gtk_image_new_from_icon_name(menu_entry [i].stock_id,
+						 GTK_ICON_SIZE_MENU);
+	  else
+	    image = gtk_image_new_from_stock (menu_entry [i].stock_id,
+					      GTK_ICON_SIZE_MENU);
 	  gtk_widget_show (image);
 
 	  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_entry [i].widget), image);
