@@ -49,7 +49,11 @@ static gchar *plugindir = NULL;
 void
 gm_platform_init ()
 {
+#if GLIB_CHECK_VERSION (2, 18, 0)
+  basedir = g_strdup (g_win32_get_package_installation_directory_of_module (NULL));
+#else  
   basedir = g_strdup (g_win32_get_package_installation_directory (NULL, NULL));
+#endif
   sysconfdir = g_strdup (basedir);
   datadir = g_strdup (basedir);
   plugindir = g_strdup_printf ("%s/lib/contacts", basedir);
